# Changelog - Pose Pipeline
All notable changes to this project will be documented in this file.
 
The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Calendar Versioning](https://calver.org/).

## [2025.05.02] - 2025-05-02
- Preparing PosePipeline for PyPI

### Added
- VitPose-H TopDown method [[#38]](https://github.com/IntelligentSensingAndRehabilitation/PosePipeline/pull/38)
- MoviTopDown HandBbox method [[#40]](https://github.com/IntelligentSensingAndRehabilitation/PosePipeline/pull/40)
- Updated README and installation instructions [[#42]](https://github.com/IntelligentSensingAndRehabilitation/PosePipeline/pull/42)
- More detailed Getting_Started notebook

### Changed
- Required Python version from ~=3.11 to >=3.10 [[#39]](https://github.com/IntelligentSensingAndRehabilitation/PosePipeline/pull/39)
- Default algorithms used for standard_pipelines

## [2024.01.14] - 2025-01-14
- Initial Release

### Added
- PosePipeline is now 'pip installable', with external dependencies automatically downloaded.
- Transition to uv as package manager [[#33]](https://github.com/IntelligentSensingAndRehabilitation/PosePipeline/pull/33)
- Breaking change with update to MMCV. [[#36]](https://github.com/IntelligentSensingAndRehabilitation/PosePipeline/pull/36)

